# Pastie

## About
This is a quick little lib I made to interact with the [pastie.io](https://pastie.io/) API.

## Use
```py
from pastie import pastie # import the pastie module
x = pastie.Paste("print('FooBar')") # storing the new paste as a var
print(x) # printing the paste URL
```

